[Libreoffice-commits] core.git: svtools/source

Luc Castermans luc.castermans at gmail.com
Thu Jan 9 10:11:29 PST 2014


 svtools/source/dialogs/mcvmath.cxx |   14 +++----
 svtools/source/svhtml/htmlout.cxx  |   17 ++++-----
 svtools/source/svhtml/parhtml.cxx  |    2 -
 svtools/source/svrtf/parrtf.cxx    |   56 +++++++++++++++----------------
 svtools/source/svrtf/rtfkeywd.cxx  |    8 ++--
 svtools/source/svrtf/rtfout.cxx    |    2 -
 svtools/source/svrtf/svparser.cxx  |   65 ++++++++++++++++++-------------------
 svtools/source/uno/unoiface.cxx    |   17 +++++----
 8 files changed, 90 insertions(+), 91 deletions(-)

New commits:
commit ee536e482b5ad01ea4a8cae79a1fcd9e12db444f
Author: Luc Castermans <luc.castermans at gmail.com>
Date:   Tue Jan 7 22:48:59 2014 +0100

    Translated German comments
    
    Reviewed on:
    	https://gerrit.libreoffice.org/7303
    
    Change-Id: I6c5f4571ad691d19ca93c39550000114f263da8b

diff --git a/svtools/source/dialogs/mcvmath.cxx b/svtools/source/dialogs/mcvmath.cxx
index 4b0141f..16551a5 100644
--- a/svtools/source/dialogs/mcvmath.cxx
+++ b/svtools/source/dialogs/mcvmath.cxx
@@ -45,11 +45,11 @@ static const short SinTab[16]=
 |*
 |*    ImpMultBig2()
 |*
-|*    Beschreibung       Multiplikation fuer FixPoint-Berechnungen
+|*    Description       Multiplier for FixPoint-calculations
 |*
 **************************************************************************/
 
-//  first parameter should be the bigger one
+//  first parameter should be the larger one
 
 Fix ImpMultBig2( const Fix& a, const Fix& b )
 {
@@ -62,7 +62,7 @@ Fix ImpMultBig2( const Fix& a, const Fix& b )
 |*
 |*    ImpSqrt()
 |*
-|*    Beschreibung       Wurzelfunktion fuer FixPoint-Berechnungen
+|*    Description       SquareRoot function for FixPoint-calculations
 |*
 **************************************************************************/
 
@@ -80,9 +80,9 @@ sal_uInt16 ImpSqrt( sal_uLong nRadi )
         sup >>= 1;
         inf <<= 1;
     }
-    sqr = (sup+inf) >> 1;               // Anfangswert der Iteration
+    sqr = (sup+inf) >> 1;               // startvalue for iteration
 
-    sqr = (nRadi/sqr + sqr) >> 1;       // 2 Newton-Iterationen reichen fuer
+    sqr = (nRadi/sqr + sqr) >> 1;       // 2 Newton-Iterations suffice for
     sqr = (nRadi/sqr + sqr) >> 1;       // +- 1 Digit
 
     return sal::static_int_cast< sal_uInt16 >(sqr);
@@ -92,11 +92,11 @@ sal_uInt16 ImpSqrt( sal_uLong nRadi )
 |*
 |*    ImpExPI()
 |*
-|*    Beschreibung       EXPI-Funktion fuer FixPoint-Berechnungen
+|*    Description       EXPI funktion or FixPoint-calculations
 |*
 **************************************************************************/
 
-// e**(i*nPhi), Einheit nPhi: 2**16 == 360 Grad
+// e**(i*nPhi), unit nPhi: 2**16 == 360 degrees
 
 FixCpx ImpExPI( sal_uInt16 nPhi )
 {
diff --git a/svtools/source/svhtml/htmlout.cxx b/svtools/source/svhtml/htmlout.cxx
index 913e4ef..22cb1a2 100644
--- a/svtools/source/svhtml/htmlout.cxx
+++ b/svtools/source/svhtml/htmlout.cxx
@@ -559,7 +559,7 @@ SvStream& HTMLOutFuncs::Out_Hex( SvStream& rStream, sal_uLong nHex, sal_uInt8 nL
     if( nLen>=sizeof(aNToABuf) )
         nLen = (sizeof(aNToABuf)-1);
 
-    // Pointer an das Bufferende setzen
+    // set pointer to end of buffer
     sal_Char *pStr = aNToABuf + (sizeof(aNToABuf)-1);
     for( sal_uInt8 n = 0; n < nLen; ++n )
     {
@@ -788,7 +788,7 @@ SvStream& HTMLOutFuncs::OutScript( SvStream& rStrm,
     if( RTL_TEXTENCODING_DONTKNOW == eDestEnc )
         eDestEnc = osl_getThreadTextEncoding();
 
-    // Script wird komplett nicht eingerueckt!
+    // script is not indented!
     OStringBuffer sOut;
     sOut.append('<')
         .append(OOO_STRING_SVTOOLS_HTML_script);
@@ -866,8 +866,8 @@ SvStream& HTMLOutFuncs::OutScript( SvStream& rStrm,
 
         if( !rSource.isEmpty() )
         {
-            // Wir schreiben das Modul mm ANSI-Zeichensatz, aber mit
-            // System-Zeilenumbruechen raus.
+            // we write the module in ANSI-charset, but with
+            // the system new line.
             const OString sSource(OUStringToOString(rSource, eDestEnc));
             rStrm << sSource.getStr() << SAL_NEWLINE_STRING;
         }
@@ -875,9 +875,8 @@ SvStream& HTMLOutFuncs::OutScript( SvStream& rStrm,
 
         if( JAVASCRIPT != eScriptType )
         {
-            // MIB/MM: Wenn es kein StarBasic ist, kann ein // natuerlich
-            // falsch sein. Da der Kommentar aber beim Einlesen wider
-            // entfernt wird, schickt uns das nicht weiter ...
+            // MIB/MM: if it is not StarBasic, a // could be wrong.
+            // As the comment is removed during reading, it is not helping us....
             rStrm << (STARBASIC == eScriptType ? "' -->" : "// -->")
                   << SAL_NEWLINE_STRING;
         }
@@ -933,7 +932,7 @@ OString HTMLOutFuncs::CreateTableDataOptionsValNum(
 
     if ( bValue )
     {
-        // printf / scanf ist zu ungenau
+        // printf / scanf is not precise enough
         OUString aValStr;
         rFormatter.GetInputLineString( fVal, 0, aValStr );
         OString sTmp(OUStringToOString(aValStr, eDestEnc));
@@ -949,7 +948,7 @@ OString HTMLOutFuncs::CreateTableDataOptionsValNum(
             append("=\"").
             append(static_cast<sal_Int32>(
                 Application::GetSettings().GetLanguageTag().getLanguageType())).
-            append(';'); // Language fuer Format 0
+            append(';'); // Language for Format 0
         if ( nFormat )
         {
             OString aNumStr;
diff --git a/svtools/source/svhtml/parhtml.cxx b/svtools/source/svhtml/parhtml.cxx
index 3263b12..9cda95d 100644
--- a/svtools/source/svhtml/parhtml.cxx
+++ b/svtools/source/svhtml/parhtml.cxx
@@ -740,7 +740,7 @@ int HTMLParser::ScanText( const sal_Unicode cBreak )
         case '\t':
             if( '\t'==nNextCh && bReadPRE && '>'!=cBreak )
             {
-                // In <PRE>: Tabs nach oben durchreichen
+                // Pass Tabs up in <PRE>
                 bContinue = false;
                 break;
             }
diff --git a/svtools/source/svrtf/rtfkeywd.cxx b/svtools/source/svrtf/rtfkeywd.cxx
index c1159e1..18f7ad1 100644
--- a/svtools/source/svrtf/rtfkeywd.cxx
+++ b/svtools/source/svrtf/rtfkeywd.cxx
@@ -25,7 +25,7 @@
 #include <ctype.h>
 #include <stdlib.h>
 
-// die Tabelle muss noch sortiert werden
+// the table is still to be sorted
 struct RTF_TokenEntry
 {
     union{
@@ -35,7 +35,7 @@ struct RTF_TokenEntry
     int nToken;
 };
 
-// Flag: RTF-Token Tabelle wurde schon sortiert
+// Flag: RTF-token table has been sorted
 static int bSortKeyWords = sal_False;
 
 static RTF_TokenEntry aRTFTokenTab[] = {
@@ -1077,7 +1077,7 @@ static RTF_TokenEntry aRTFTokenTab[] = {
         {{OOO_STRING_SVTOOLS_RTF_NOOVERFLOW},    RTF_NOOVERFLOW},
         {{OOO_STRING_SVTOOLS_RTF_ASPALPHA},      RTF_ASPALPHA},
 
-// SWG spezifische Attribute
+// SWG specific attributes
         {{OOO_STRING_SVTOOLS_RTF_GRFALIGNV},     RTF_GRF_ALIGNV},
         {{OOO_STRING_SVTOOLS_RTF_GRFALIGNH},     RTF_GRF_ALIGNH},
         {{OOO_STRING_SVTOOLS_RTF_GRFMIRROR},     RTF_GRF_MIRROR},
@@ -1094,7 +1094,7 @@ static RTF_TokenEntry aRTFTokenTab[] = {
         {{OOO_STRING_SVTOOLS_RTF_PRTDATA},       RTF_SWG_PRTDATA},
         {{OOO_STRING_SVTOOLS_RTF_BKMKKEY},       RTF_BKMK_KEY},
 
-// Attribute fuer die freifliegenden Rahmen
+// Attributes for fly frames
         {{OOO_STRING_SVTOOLS_RTF_FLYPRINT},      RTF_FLYPRINT},
         {{OOO_STRING_SVTOOLS_RTF_FLYOPAQUE},     RTF_FLYOPAQUE},
         {{OOO_STRING_SVTOOLS_RTF_FLYPRTCTD},     RTF_FLYPRTCTD},
diff --git a/svtools/source/svrtf/rtfout.cxx b/svtools/source/svrtf/rtfout.cxx
index 5727a4b..682e99c 100644
--- a/svtools/source/svrtf/rtfout.cxx
+++ b/svtools/source/svrtf/rtfout.cxx
@@ -166,7 +166,7 @@ SvStream& RTFOutFuncs::Out_Hex( SvStream& rStream, sal_uLong nHex, sal_uInt8 nLe
     if( nLen >= sizeof(aNToABuf) )
         nLen = (sizeof(aNToABuf)-1);
 
-    // Pointer an das Bufferende setzen
+    // set pointer to end of buffer
     sal_Char* pStr = aNToABuf + (sizeof(aNToABuf)-1);
     for( sal_uInt8 n = 0; n < nLen; ++n )
     {
diff --git a/svtools/source/svrtf/svparser.cxx b/svtools/source/svrtf/svparser.cxx
index 4647a2f..5365a56 100644
--- a/svtools/source/svrtf/svparser.cxx
+++ b/svtools/source/svrtf/svparser.cxx
@@ -24,19 +24,18 @@
 #include <rtl/textcvt.h>
 #include <rtl/tencinfo.h>
 
-// Struktur, um sich die akt. Daten zumerken
+// structure to store the actuel data
 struct SvParser_Impl
 {
-    OUString          aToken;             // gescanntes Token
-    sal_uLong           nFilePos;           // akt. Position im Stream
-    sal_uLong           nlLineNr;           // akt. Zeilen Nummer
-    sal_uLong           nlLinePos;          // akt. Spalten Nummer
-    long            nTokenValue;        // zusaetzlicher Wert (RTF)
-    sal_Bool            bTokenHasValue;     // indicates whether nTokenValue is valid
-    int             nToken;             // akt. Token
-    sal_Unicode     nNextCh;            // akt. Zeichen
-
-    int             nSaveToken;         // das Token vom Continue
+    OUString        aToken;             // gescanntes Token
+    sal_uLong       nFilePos;           // actual position in stream
+    sal_uLong       nlLineNr;           // actual line number
+    sal_uLong       nlLinePos;          // actual column number
+    long            nTokenValue;        // extra value (RTF)
+    sal_Bool        bTokenHasValue;     // indicates whether nTokenValue is valid
+    int             nToken;             // actual Token
+    sal_Unicode     nNextCh;            // actual character
+    int             nSaveToken;         // the token from Continue
 
     rtl_TextToUnicodeConverter hConv;
     rtl_TextToUnicodeContext   hContext;
@@ -50,7 +49,7 @@ struct SvParser_Impl
 
 
 
-// Konstruktor
+// Construktor
 SvParser::SvParser( SvStream& rIn, sal_uInt8 nStackSize )
     : rInput( rIn )
     , nlLineNr( 1 )
@@ -382,8 +381,8 @@ int SvParser::GetNextToken()
 
     if( !nTokenStackPos )
     {
-        aToken = "";     // Token-Buffer loeschen
-        nTokenValue = -1;   // Kennzeichen fuer kein Value gelesen
+        aToken = "";     // empty token buffer
+        nTokenValue = -1;   // marker for no value read
         bTokenHasValue = false;
 
         nRet = _GetNextToken();
@@ -395,7 +394,7 @@ int SvParser::GetNextToken()
     if( pTokenStackPos == pTokenStack + nTokenStackSize )
         pTokenStackPos = pTokenStack;
 
-    // vom Stack holen ??
+    // pop from stack ??
     if( nTokenStackPos )
     {
         --nTokenStackPos;
@@ -404,7 +403,7 @@ int SvParser::GetNextToken()
         aToken = pTokenStackPos->sToken;
         nRet = pTokenStackPos->nTokenId;
     }
-    // nein, dann das aktuelle auf den Stack
+    // no, now push actual value on stack
     else if( SVPAR_WORKING == eState )
     {
         pTokenStackPos->sToken = aToken;
@@ -413,12 +412,12 @@ int SvParser::GetNextToken()
         pTokenStackPos->nTokenId = nRet;
     }
     else if( SVPAR_ACCEPTED != eState && SVPAR_PENDING != eState )
-        eState = SVPAR_ERROR;       // irgend ein Fehler
+        eState = SVPAR_ERROR;       // an error occured
 
     return nRet;
 }
 
-int SvParser::SkipToken( short nCnt )       // n Tokens zurueck "skippen"
+int SvParser::SkipToken( short nCnt )       // "skip" n Tokens backward
 {
     pTokenStackPos = GetStackPtr( nCnt );
     short nTmp = nTokenStackPos - nCnt;
@@ -428,7 +427,7 @@ int SvParser::SkipToken( short nCnt )       // n Tokens zurueck "skippen"
         nTmp = nTokenStackSize;
     nTokenStackPos = sal_uInt8(nTmp);
 
-    // und die Werte zurueck
+    // restore values
     aToken = pTokenStackPos->sToken;
     nTokenValue = pTokenStackPos->nTokenValue;
     bTokenHasValue = pTokenStackPos->bTokenHasValue;
@@ -462,13 +461,13 @@ SvParser::TokenStackType* SvParser::GetStackPtr( short nCnt )
     return pTokenStack + nAktPos;
 }
 
-// wird fuer jedes Token gerufen, das in CallParser erkannt wird
+// is called for each token which is recognised by CallParser
 void SvParser::NextToken( int )
 {
 }
 
 
-// fuers asynchrone lesen aus dem SvStream
+// to read asynchronous from SvStream
 
 int SvParser::GetSaveToken() const
 {
@@ -477,7 +476,7 @@ int SvParser::GetSaveToken() const
 
 void SvParser::SaveState( int nToken )
 {
-    // aktuellen Status merken
+    // save actual status
     if( !pImplData )
     {
         pImplData = new SvParser_Impl;
@@ -497,7 +496,7 @@ void SvParser::SaveState( int nToken )
 
 void SvParser::RestoreState()
 {
-    // alten Status wieder zurueck setzen
+    // restore old status
     if( pImplData )
     {
         if( ERRCODE_IO_PENDING == rInput.GetError() )
@@ -531,19 +530,19 @@ void SvParser::BuildWhichTbl( std::vector<sal_uInt16> &rWhichMap,
             aNewRange[0] = aNewRange[1] = *pWhichIds;
             sal_Bool bIns = sal_True;
 
-            // Position suchen
+            // search position
             for ( sal_uInt16 nOfs = 0; rWhichMap[nOfs]; nOfs += 2 )
             {
                 if( *pWhichIds < rWhichMap[nOfs] - 1 )
                 {
-                    // neuen Range davor
+                    // new range before
                     rWhichMap.insert( rWhichMap.begin() + nOfs, aNewRange, aNewRange + 2 );
                     bIns = sal_False;
                     break;
                 }
                 else if( *pWhichIds == rWhichMap[nOfs] - 1 )
                 {
-                    // diesen Range nach unten erweitern
+                    // extend range downwards
                     rWhichMap[nOfs] = *pWhichIds;
                     bIns = sal_False;
                     break;
@@ -552,20 +551,20 @@ void SvParser::BuildWhichTbl( std::vector<sal_uInt16> &rWhichMap,
                 {
                     if( rWhichMap[nOfs+2] != 0 && rWhichMap[nOfs+2] == *pWhichIds + 1 )
                     {
-                        // mit dem naechsten Bereich mergen
+                        // merge with next field
                         rWhichMap[nOfs+1] = rWhichMap[nOfs+3];
                         rWhichMap.erase( rWhichMap.begin() + nOfs + 2,
                                 rWhichMap.begin() + nOfs + 4 );
                     }
                     else
-                        // diesen Range nach oben erweitern
+                        // extend range upwards
                         rWhichMap[nOfs+1] = *pWhichIds;
                     bIns = sal_False;
                     break;
                 }
             }
 
-            // einen Range hinten anhaengen
+            // append range
             if( bIns )
             {
                 rWhichMap.insert( rWhichMap.begin() + rWhichMap.size() - 1,
@@ -580,8 +579,8 @@ IMPL_STATIC_LINK( SvParser, NewDataRead, void*, EMPTYARG )
     switch( pThis->eState )
     {
     case SVPAR_PENDING:
-        // Wenn gerade ein File geladen wird duerfen wir nicht weiterlaufen,
-        // sondern muessen den Aufruf ignorieren.
+        // if file is loaded we are not allowed to continue
+        // instead should ignore the call.
         if( pThis->IsDownloadingFile() )
             break;
 
@@ -594,7 +593,7 @@ IMPL_STATIC_LINK( SvParser, NewDataRead, void*, EMPTYARG )
             pThis->rInput.ResetError();
 
         if( SVPAR_PENDING != pThis->eState )
-            pThis->ReleaseRef();                    // ansonsten sind wir fertig!
+            pThis->ReleaseRef();                    // ready otherwise!
         break;
 
     case SVPAR_WAITFORDATA:
@@ -606,7 +605,7 @@ IMPL_STATIC_LINK( SvParser, NewDataRead, void*, EMPTYARG )
         break;
 
     default:
-        pThis->ReleaseRef();                    // ansonsten sind wir fertig!
+        pThis->ReleaseRef();                    // ready otherwise!
         break;
     }
 
diff --git a/svtools/source/uno/unoiface.cxx b/svtools/source/uno/unoiface.cxx
index e0cf91e..d8c3721 100644
--- a/svtools/source/uno/unoiface.cxx
+++ b/svtools/source/uno/unoiface.cxx
@@ -621,8 +621,8 @@ void VCLXFileControl::setText( const OUString& aText ) throw(::com::sun::star::u
     {
         pWindow->SetText( aText );
 
-        // In JAVA wird auch ein textChanged ausgeloest, in VCL nicht.
-        // ::com::sun::star::awt::Toolkit soll JAVA-komform sein...
+        // also in Java a textChanged is triggered, not in VCL.
+        // ::com::sun::star::awt::Toolkit should be JAVA-compliant...
         ModifyHdl( NULL );
     }
 }
@@ -1245,7 +1245,7 @@ void SVTXFormattedField::SetTreatAsNumber(sal_Bool bSet)
     }
     else
     {
-        if (!pField->GetText().isEmpty())    // empty wird erst mal standardmaessig als void nach draussen gereicht
+        if (!pField->GetText().isEmpty())    // empty is returned as void by default
             aReturn <<= pField->GetValue();
     }
 
@@ -1313,7 +1313,7 @@ void SVTXFormattedField::setFormatsSupplier(const ::com::sun::star::uno::Referen
     }
 
     if (!pNew)
-        return;     // TODO : wie das behandeln ?
+        return;     // TODO : how to process ?
 
     if (m_pCurrentSupplier)
         m_pCurrentSupplier->release();
@@ -1321,7 +1321,7 @@ void SVTXFormattedField::setFormatsSupplier(const ::com::sun::star::uno::Referen
     m_pCurrentSupplier->acquire();
     if (pField)
     {
-        // den aktuellen Value mit hinueberretten
+        // save the actual value
         ::com::sun::star::uno::Any aCurrent = GetValue();
         pField->SetFormatter(m_pCurrentSupplier->GetNumberFormatter(), sal_False);
         if (nKeyToSetDelayed != -1)
@@ -1350,9 +1350,10 @@ void SVTXFormattedField::setFormatKey(sal_Int32 nKey)
         if (pField->GetFormatter())
             pField->SetFormatKey(nKey);
         else
-        {   // Wahrscheinlich bin ich gerade in einem Block, in dem erst der Key und dann der Formatter gesetzt
-            // wird, das passiert initial mit ziemlicher Sicherheit, da die Properties in alphabetischer Reihenfolge
-            // gesetzt werden, und der FormatsSupplier nun mal vor dem FormatKey kommt
+        {
+            // probably I am in a block, in which first the key and next the formatter will be set,
+            // initially this happens quite certain, as the properties are set in alphabettic sequence,
+            // and the FormatsSupplier is processed before the FormatKey
             nKeyToSetDelayed = nKey;
         }
         NotifyTextListeners();


More information about the Libreoffice-commits mailing list
diff --git a/svtools/source/svrtf/parrtf.cxx b/svtools/source/svrtf/parrtf.cxx
index a6d974d..1c28b78 100644
--- a/svtools/source/svrtf/parrtf.cxx
+++ b/svtools/source/svrtf/parrtf.cxx
@@ -59,13 +59,13 @@ int SvRTFParser::_GetNextToken()
         {
         case '\\':
             {
-                // Steuerzeichen
+                // control charaters
                 switch( nNextCh = GetNextChar() )
                 {
                 case '{':
                 case '}':
                 case '\\':
-                case '+':       // habe ich in einem RTF-File gefunden
+                case '+':       // I found it in a RTF-file
                 case '~':       // nonbreaking space
                 case '-':       // optional hyphen
                 case '_':       // nonbreaking hyphen
@@ -83,7 +83,7 @@ int SvRTFParser::_GetNextToken()
                 case ':':       // subentry in an index entry
                     nRet = RTF_SUBENTRYINDEX;
                     break;
-                case '|':       // formula-charakter
+                case '|':       // formula-character
                     nRet = RTF_FORMULA;
                     break;
 
@@ -115,7 +115,7 @@ int SvRTFParser::_GetNextToken()
                             }
                         }
 
-                        // Minus fuer numerischen Parameter
+                        // minus before numeric parameters
                         int bNegValue = false;
                         if( '-' == nNextCh )
                         {
@@ -123,7 +123,7 @@ int SvRTFParser::_GetNextToken()
                             nNextCh = GetNextChar();
                         }
 
-                        // evt. Numerischer Parameter
+                        // possible numeric parameter
                         if( RTF_ISDIGIT( nNextCh ) )
                         {
                             nTokenValue = 0;
@@ -136,15 +136,15 @@ int SvRTFParser::_GetNextToken()
                                 nTokenValue = -nTokenValue;
                             bTokenHasValue=true;
                         }
-                        else if( bNegValue )        // das Minus wieder zurueck
+                        else if( bNegValue )        // restore minus
                         {
                             nNextCh = '-';
                             rInput.SeekRel( -1 );
                         }
-                        if( ' ' == nNextCh )        // Blank gehoert zum Token!
+                        if( ' ' == nNextCh )        // blank is part of token!
                             nNextCh = GetNextChar();
 
-                        // suche das Token in der Tabelle:
+                        // search for the token in the table:
                         if( 0 == (nRet = GetRTFToken( aToken )) )
                             // Unknown Control
                             nRet = RTF_UNKNOWNCONTROL;
@@ -196,7 +196,7 @@ int SvRTFParser::_GetNextToken()
 
                                     if( '\\' == cAnsi &&
                                         '\'' == ( cAnsi = GetNextChar() ))
-                                        // HexValue ueberlesen
+                                        // read on HexValue
                                         cAnsi = GetHexValue();
                                     nNextCh = GetNextChar();
                                 }
@@ -208,7 +208,7 @@ int SvRTFParser::_GetNextToken()
                     }
                     else if( SVPAR_PENDING != eState )
                     {
                         // Bug 34631 - "\ " ueberlesen - Blank als Zeichen
                         // eState = SVPAR_ERROR;
                         bNextCh = false;
                     }
@@ -266,7 +266,7 @@ int SvRTFParser::_GetNextToken()
             break;
 
         default:
-            // es folgt normaler Text
+            // now normal text follows
             ScanText();
             nRet = RTF_TEXTTOKEN;
             bNextCh = 0 == nNextCh;
@@ -283,7 +283,7 @@ int SvRTFParser::_GetNextToken()
 
 sal_Unicode SvRTFParser::GetHexValue()
 {
-    // Hex-Wert sammeln
+    // collect Hex values
     int n;
     sal_Unicode nHexVal = 0;
 
@@ -377,7 +377,7 @@ void SvRTFParser::ScanText( const sal_Unicode cBreak )
                 case '\\':
                 case '}':
                 case '{':
-                case '+':       // habe ich in einem RTF-File gefunden
+                case '+':       // I found in a RTF file
                     aStrBuffer.append(nNextCh);
                     break;
                 case '~':       // nonbreaking space
@@ -391,7 +391,7 @@ void SvRTFParser::ScanText( const sal_Unicode cBreak )
                     break;
 
                 case 'u':
-                    // UNI-Code Zeichen lesen
+                    // read UNI-Code characters
                     {
                         nNextCh = GetNextChar();
                         rInput.SeekRel( -2 );
@@ -433,7 +433,7 @@ void SvRTFParser::ScanText( const sal_Unicode cBreak )
                         else
                         {
                             nNextCh = '\\';
-                            bContinue = false;        // Abbrechen, String zusammen
+                            bContinue = false;        // abort, string together
                         }
                     }
                     break;
@@ -441,7 +441,7 @@ void SvRTFParser::ScanText( const sal_Unicode cBreak )
                 default:
                     rInput.SeekRel( -1 );
                     nNextCh = '\\';
-                    bContinue = false;        // Abbrechen, String zusammen
+                    bContinue = false;        // abort, string together
                     break;
                 }
             }
@@ -449,7 +449,7 @@ void SvRTFParser::ScanText( const sal_Unicode cBreak )
 
         case sal_Unicode(EOF):
                 eState = SVPAR_ERROR;
-                // weiter
+                // continue
         case '{':
         case '}':
             bContinue = false;
@@ -465,7 +465,7 @@ void SvRTFParser::ScanText( const sal_Unicode cBreak )
             else
             {
                 do {
-                    // alle anderen Zeichen kommen in den Text
+                    // all other characters end up in the text
                     aStrBuffer.append(nNextCh);
 
                     if (sal_Unicode(EOF) == (nNextCh = GetNextChar()))
@@ -546,15 +546,15 @@ SvParserState SvRTFParser::CallParser()
     eState = SVPAR_WORKING;
     nOpenBrakets = 0;
     SetSrcEncoding( eCodeSet = RTL_TEXTENCODING_MS_1252 );
-    eUNICodeSet = RTL_TEXTENCODING_MS_1252;     // default ist ANSI-CodeSet
+    eUNICodeSet = RTL_TEXTENCODING_MS_1252;     // default is ANSI-CodeSet
 
-    // die 1. beiden Token muessen '{' und \\rtf sein !!
+    // the first two tokens should be '{' and \\rtf !!
     if( '{' == GetNextToken() && RTF_RTF == GetNextToken() )
     {
         AddRef();
         Continue( 0 );
         if( SVPAR_PENDING != eState )
-            ReleaseRef();       // dann brauchen wir den Parser nicht mehr!
+            ReleaseRef();       // now parser is not needed anymore
     }
     else
         eState = SVPAR_ERROR;
@@ -565,7 +565,7 @@ SvParserState SvRTFParser::CallParser()
 void SvRTFParser::Continue( int nToken )
 {
 //  DBG_ASSERT( SVPAR_CS_DONTKNOW == GetCharSet(),
-//              "Zeichensatz wurde geaendert." );
+//              "Characterset was changed." );
 
     if( !nToken )
         nToken = GetNextToken();
@@ -582,7 +582,7 @@ void SvRTFParser::Continue( int nToken )
             break;
 
         case '{':
-            // eine unbekannte Gruppe ?
+            // a unknown group ?
             {
                 if( RTF_IGNOREFLAG != GetNextToken() )
                     nToken = SkipToken( -1 );
@@ -590,18 +590,18 @@ void SvRTFParser::Continue( int nToken )
                     nToken = SkipToken( -2 );
                 else
                 {
-                    // gleich herausfiltern
+                    // filter immediately
                     ReadUnknownData();
                     nToken = GetNextToken();
                     if( '}' != nToken )
                         eState = SVPAR_ERROR;
-                    break;      // auf zum naechsten Token!!
+                    break;      // move to next token!!
                 }
             }
             goto NEXTTOKEN;
 
         case RTF_UNKNOWNCONTROL:
-            break;      // unbekannte Token ueberspringen
+            break;      // skip unknown token
         case RTF_NEXTTYPE:
         case RTF_ANSITYPE:
             SetSrcEncoding( eCodeSet = RTL_TEXTENCODING_MS_1252 );
@@ -625,8 +625,8 @@ NEXTTOKEN:
             break;
         }
         if( IsParserWorking() )
-            SaveState( 0 );         // bis hierhin abgearbeitet,
-                                    // weiter mit neuem Token!
+            SaveState( 0 );         // processed till here,
+                                    // continue with new token!
         nToken = GetNextToken();
     }
     if( SVPAR_ACCEPTED == eState && 0 < nOpenBrakets )
@@ -208,7 +208,7 @@ int SvRTFParser::_GetNextToken()
                     else if( SVPAR_PENDING != eState )
                     {
-                        // Bug 34631 - "\ " ueberlesen - Blank als Zeichen
+                        // Bug 34631 - "\ " read on - Blank as character
                         // eState = SVPAR_ERROR;
                         bNextCh = false;